@@ -33,11 +33,12 @@ def search_obj_from_array(array, fieldname, fieldvalue):
 
 class Timer(object):
 
-    def __init__(self, logger=None, logger_name='timings'):
+    def __init__(self, info=None, logger=None, logger_name='timings'):
 
         self.start = time.time()
         self.end = None
         self.timings = []
+        self.info = info
         self.logger = logger or logging.getLogger(logger_name)
 
     def register(self, name, info=None):
@@ -71,6 +72,7 @@ class Timer(object):
                 'start': pytz.utc.localize(datetime.datetime.utcfromtimestamp(self.start)).isoformat(),
                 'end': pytz.utc.localize(datetime.datetime.utcfromtimestamp(self.end)).isoformat(),
                 'duration': self.total,
+                'info': self.info,
                 'timings': timings
             }
         else:
